diff a/src/hotspot/share/runtime/sharedRuntime.hpp b/src/hotspot/share/runtime/sharedRuntime.hpp
--- a/src/hotspot/share/runtime/sharedRuntime.hpp
+++ b/src/hotspot/share/runtime/sharedRuntime.hpp
@@ -515,10 +515,25 @@
   static address handle_wrong_method_abstract(JavaThread* current);
   static address handle_wrong_method_ic_miss(JavaThread* current);
 
   static address handle_unsafe_access(JavaThread* thread, address next_pc);
 
+ private:
+  static PerfTickCounters* _perf_resolve_opt_virtual_total_time;
+  static PerfTickCounters* _perf_resolve_virtual_total_time;
+  static PerfTickCounters* _perf_resolve_static_total_time;
+  static PerfTickCounters* _perf_handle_wrong_method_total_time;
+  static PerfTickCounters* _perf_ic_miss_total_time;
+ public:
+  static uint _ic_miss_ctr;                      // total # of IC misses
+  static uint _wrong_method_ctr;
+  static uint _resolve_static_ctr;
+  static uint _resolve_virtual_ctr;
+  static uint _resolve_opt_virtual_ctr;
+
+  static void print_counters_on(outputStream* st);
+
 #ifndef PRODUCT
 
   // Collect and print inline cache miss statistics
  private:
   enum { maxICmiss_count = 100 };
@@ -526,15 +541,10 @@
   static int     _ICmiss_count[maxICmiss_count]; // miss counts
   static address _ICmiss_at[maxICmiss_count];    // miss addresses
   static void trace_ic_miss(address at);
 
  public:
-  static uint _ic_miss_ctr;                      // total # of IC misses
-  static uint _wrong_method_ctr;
-  static uint _resolve_static_ctr;
-  static uint _resolve_virtual_ctr;
-  static uint _resolve_opt_virtual_ctr;
   static uint _implicit_null_throws;
   static uint _implicit_div0_throws;
 
   static uint _jbyte_array_copy_ctr;       // Slow-path byte array copy
   static uint _jshort_array_copy_ctr;      // Slow-path short array copy
@@ -574,13 +584,13 @@
   static address nof_inlined_calls_addr()               { return (address)&_nof_inlined_calls; }
   static address nof_static_calls_addr()                { return (address)&_nof_static_calls; }
   static address nof_inlined_static_calls_addr()        { return (address)&_nof_inlined_static_calls; }
   static address nof_interface_calls_addr()             { return (address)&_nof_interface_calls; }
   static address nof_inlined_interface_calls_addr()     { return (address)&_nof_inlined_interface_calls; }
-  static void print_call_statistics(uint64_t comp_total);
-  static void print_ic_miss_histogram();
 
+  static void print_call_statistics_on(outputStream* st);
+  static void print_ic_miss_histogram_on(outputStream* st);
 #endif // PRODUCT
 
   static void print_statistics() PRODUCT_RETURN;
 };
 
@@ -701,11 +711,11 @@
 
   static void print_handler(const CodeBlob* b) { print_handler_on(tty, b); }
   static void print_handler_on(outputStream* st, const CodeBlob* b);
   static bool contains(const CodeBlob* b);
 #ifndef PRODUCT
-  static void print_statistics();
+  static void print_statistics_on(outputStream* st);
 #endif // PRODUCT
 
 };
 
 #endif // SHARE_RUNTIME_SHAREDRUNTIME_HPP
